@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::env;
-$App::gimpgitbuild::Command::env::VERSION = '0.2.0';
+$App::gimpgitbuild::Command::env::VERSION = '0.2.1';
 use strict;
 use warnings;
 use 5.014;
@@ -12,7 +12,7 @@ use App::gimpgitbuild::API::GitBuild ();
 
 sub description
 {
-    return "build gimp from git";
+    return "set the environment for using or building GIMP-from-git";
 }
 
 sub abstract
@@ -100,7 +100,7 @@ __END__
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
